%define upstream_name    razor-agents
%define upstream_version 2.85

# Filter the Perl extension module
%{?perl_default_filter}

Name:       perl-Razor-Agent
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 18
Summary:    Use a Razor catalogue server to filter spam messages
Group:      Networking/Mail
License:    Artistic License 2.0
Url:        http://razor.sourceforge.net
Source0:    http://prdownloads.sourceforge.net/razor/%{upstream_name}-%{upstream_version}.tar.bz2

BuildRequires: perl(Digest::SHA1)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Copy)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Getopt::Long)
BuildRequires: perl(MIME::Base64)
BuildRequires: perl(Test::More)
BuildRequires: perl(Time::HiRes)
BuildRequires: perl(URI::Escape)
BuildRequires: perl-devel
BuildRequires: perl-Net-DNS
BuildRequires: perl-MailTools
Requires:   perl-Net-DNS
Requires(post):   hping3

%description
Vipul's Razor is a distributed, collaborative, spam detection and filtering
network. Razor establishes a distributed and constantly updating catalogue of
spam in propagation.  This catalogue is used by clients to filter out known
spam. On receiving a spam, a Razor Reporting Agent (run by an end-user or a
troll box) calculates and submits a 20-character unique identification of the
spam (a SHA Digest) to its closest Razor Catalogue Server. The Catalogue Server
echos this signature to other trusted servers after storing it in its database.
Prior to manual processing or transport-level reception, Razor Filtering Agents
(end-users and MTAs) check their incoming mail against a Catalogue Server and
filter out or deny transport in case of a signature match. Catalogued spam,
once identified and reported by a Reporting Agent, can be blocked out by the
rest of the Filtering Agents on the network.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%serverbuild

%{__perl} Makefile.PL INSTALLDIRS=vendor

pushd Razor2-Preproc-deHTMLxs
    %{__perl} Makefile.PL INSTALLDIRS=vendor
popd

%make OPTIMIZE="$CFLAGS" 


pushd Razor2-Preproc-deHTMLxs
popd

%install
pushd Razor2-Preproc-deHTMLxs
%makeinstall_std
popd

%makeinstall_std

install -d %{buildroot}%{_mandir}/man5
install -m0644 blib/man5/*.5 %{buildroot}%{_mandir}/man5

# fix some defaults
install -d %{buildroot}%{_sysconfdir}/logrotate.d
install -d %{buildroot}/var/log/razor
install -d %{buildroot}%{_sysconfdir}/razor

cat > %{buildroot}%{_sysconfdir}/razor/razor-agent.conf << EOF
logfile                = /var/log/razor/razor-agent.log
EOF

# fix logrotating
cat > %{buildroot}%{_sysconfdir}/logrotate.d/razor-agent << EOF
/var/log/razor/razor-agent.log {
    # create 644 root root
    weekly
    notifempty
    missingok
    compress
}
EOF

%post
# only do this if we have a working network and if the config file contains just one line
if [ "`cat %{_sysconfdir}/razor/razor-agent.conf|wc -l`" -eq "1" ] ; then
    if /usr/sbin/hping -c 4 -p 2703 --tcpexitcode discovery.razor.cloudmark.com >/dev/null 2>&1; then
        %{_bindir}/razor-admin -d -create -home=%{_sysconfdir}/razor
    else
        echo "You might want to run \"%{_bindir}/razor-admin -d -create -home=%{_sysconfdir}/razor\" when your network works"
    fi
fi

%files
%doc BUGS CREDITS Changes FAQ INSTALL LICENSE META.yml MYMETA.yml README
%attr(0755,root,root) %dir %{_sysconfdir}/razor
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/razor/razor-agent.conf
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/razor-agent
%{_bindir}/*
%{perl_vendorlib}/Razor2
%{perl_vendorlib}/auto/Razor2
%{perl_vendorarch}/Razor2
%{perl_vendorarch}/auto/Razor2
%{_mandir}/*/*
%attr(0755,root,root) %dir /var/log/razor


%changelog
* Wed Jul 12 2017 bb2 <bb2> - 2.850.0-18pclos2017
- rebuild against updates

